====================
``xeofs.validation``
====================
Tools to assess the significane of your model.

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   ~xeofs.validation.EOFBootstrapper
